import pandas as pd

def add_func(a:int, b:int)->int:
    """
        This function takes 2 number and returns addition of it
        Args:
            a:int : number 1
            b:int : number 2
    """
    return a + b

def sub_func(a:int, b:int)->int:
    """
        This function takes 2 number and returns substraction of it
        Args:
            a:int : number 1
            b:int : number 2
    """
    return a - b

def create_df(lst:list)->int:
    """
        This function takes 1 list of list ([[]]) and returns dataframe of it
        Args:
            a:int : number 1
    """
    return pd.DataFrame(lst)


import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of README file
README = (HERE / "README.md").read_text()

# This is a call to setup does all setup works.
setup(
    name="simplecalq",
    version="0.0.1",
    description="simple python library to demonstrate python tooling",
    long_description=README,
    url="",
    author="BrainStorm",
    author_email="dhiraj@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8"
    ],
    packages=["calculator"],
    include_package_data=True,
    install_requires=["pandas"]
)